package api

import (
	"errors"
	"moutai/db/model"
	"moutai/db/repo"
	"moutai/log"
	"time"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func CreateAr(c *gin.Context, apictx *ApiSession) (interface{}, error) {

	ar := &model.Ar{}
	err := c.ShouldBindJSON(&ar)
	if err != nil {
		log.Error(err)
		return nil, err
	}

	defuealt := 0
	ar.Clicks = &defuealt
	ar.Sort = getSortInt(apictx, repo.CollectionAr) + 1
	// 正常状态
	state := -1
	ar.State = &state
	ar.CreateTime = time.Now()
	ar.UpdateTime = time.Now()
	return repo.RepoAddDoc(apictx.CreateRepoCtx(), repo.CollectionAr, &ar)
}

func DeleteAr(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	return repo.RepoDeleteDoc(apictx.CreateRepoCtx(), repo.CollectionAr, _id)
}

func ArList(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	page, size, query := UtilQueryPageSize(c)
	query, sort := getQuery(query)
	result, err := repo.RepoPageSearch(apictx.CreateRepoCtx(), &repo.PageSearchOptions{
		CollectName: repo.CollectionAr,
		Page:        page,
		Size:        size,
		Query:       query,
		Sort:        sort,
	})

	cate := model.Catgory{}
	if len(result.List) > 0 {
		for i, u := range result.List {
			if v, ok := u["cid"]; ok {
				// 查询角色信息
				cid := v.(primitive.ObjectID)
				repo.RepoSeachDoc(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
					CollectName: repo.CollectionCategories,
					Query:       repo.Map{"_id": cid},
				}, &cate)
			}
			// 拼接角色信息
			result.List[i]["cateInfo"] = cate
		}
	}
	return result, err
}

func UpdateAr(c *gin.Context, apictx *ApiSession) (interface{}, error) {

	Ar := &model.Ar{}
	err := c.ShouldBindJSON(&Ar)
	if err != nil {
		log.Error(err)
		return nil, err
	}
	if Ar.Id.IsZero() {
		return nil, errors.New("id错误")
	}

	Ar.UpdateTime = time.Now()
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionAr, Ar.Id.Hex(), Ar)
}

func ArOn(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	state := 1
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionAr, _id, model.Ar{State: &state})
}

func ArOff(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	state := -1
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionAr, _id, model.Ar{State: &state})
}
